@@ -13,7 +13,7 @@
 ##############################################################################
 """test resolution of dotted names
 
-$Id: tests.py 93550 2008-12-02 21:09:23Z chrisw $
+$Id: tests.py 95186 2009-01-27 13:41:49Z thefunny42 $
 """
 import os,unittest
 from zope.testing.doctest import DocFileSuite,REPORT_NDIFF,ELLIPSIS
@@ -22,7 +22,8 @@ def test_suite():
     return unittest.TestSuite((
         DocFileSuite(
             os.path.abspath(os.path.join(os.path.dirname(__file__),'..','..','..','README.txt')),
-            optionflags=REPORT_NDIFF|ELLIPSIS
+            optionflags=REPORT_NDIFF|ELLIPSIS,
+            module_relative=False,
             ),
         ))
 
